# Mainly inspired from Fedora's .spec

%define major        1
%define libname      %mklibname %{name} %{major}
%define libnametrace %mklibname %{name}-trace %{major}
%define libnamedevel %mklibname %{name} -d

Name:           picosat
Summary:        Lightweight SAT solver
Version:        965
Release:        %mkrel 4
Source0:        https://fmv.jku.at/%{name}/%{name}-%{version}.tar.gz
URL:            https://fmv.jku.at/picosat/
# Thanks to David Wheeler for the man page.
Source1:        picosat.1
# Man page link for picosat.trace
Source2:        picosat.trace.1
# Man page for picomus
Source3:        picomus.1
# This patch has not been sent upstream.  It is specific to Fedora's build of
# two distinct binaries, one with trace support and one without.
Patch0:         picosat-trace.patch

Group:          Sciences/Computer science
License:        MIT-like
# gzip required (see app.c); find-requires can't see into C code to find it
Requires:       gzip

%description
The SAT problem is the classical NP complete problem of searching
for a satisfying assignment of a propositional formula in
conjunctive normal form (CNF). General information on SAT can be
found at http://www.satlive.org or http://www.satlib.org.

%package -n     %{libname}
Group:          Development/C
Summary:        A SAT solver library

%description -n %{libname}
The PicoSAT library, which contains routines that solve the SAT problem.
The library has a simple API which is similar to that of previous
solvers by the same authors.

%package -n     %{libnametrace}
Group:          Development/C
Summary:        A SAT solver library

%description -n %{libnametrace}
The PicoSAT library, which contains routines that solve the SAT problem.
The library has a simple API which is similar to that of previous
solvers by the same authors.

%package -n     %{libnamedevel}
Group:          Development/C
Summary:        Development files for PicoSAT
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < 965-3

%description -n %{libnamedevel}
Headers and other development files for PicoSAT.

%prep
%autosetup -p0

%build
# The configure script is NOT autoconf-generated and chooses its own CFLAGS,
# so we mimic its effects instead of using it.

# Build the version with trace support
sed -e "s|@CC@|gcc|" \
    -e "s|@CFLAGS@|${RPM_OPT_FLAGS} -DTRACE -DNDEBUG|" \
    -e "s|-Xlinker libpicosat.so|-Xlinker libpicosat.so.%{major}|" \
    -e "s|libpicosat|libpicosat-trace|g" \
    -e "s|-lpicosat|-lpicosat-trace|g" \
    -e "s|@TARGETS@|libpicosat-trace.so picosat picomus|" \
  makefile.in > makefile
make
mv picosat picosat.trace

# Build the fast version.
# Note that picomus needs trace support, so we don't rebuild it.
rm -f *.o *.s config.h
sed -e "s|@CC@|gcc|" \
    -e "s|@CFLAGS@|${RPM_OPT_FLAGS} -DNDEBUG|" \
    -e "s|-Xlinker libpicosat.so|-Xlinker libpicosat.so.%{major}|" \
    -e "s|@TARGETS@|libpicosat.so picosat|" \
  makefile.in > makefile
make

%install
# Install the header file
mkdir -p $RPM_BUILD_ROOT%{_includedir}/%{name}
cp -p picosat.h $RPM_BUILD_ROOT%{_includedir}/%{name}

# Install the libraries
mkdir -p $RPM_BUILD_ROOT%{_libdir}
cp -p libpicosat-trace.so $RPM_BUILD_ROOT%{_libdir}/libpicosat-trace.so.%{major}.0.%{version}
ln -s libpicosat-trace.so.%{major}.0.%{version} $RPM_BUILD_ROOT%{_libdir}/libpicosat-trace.so.%{major}
ln -s libpicosat-trace.so.%{major} $RPM_BUILD_ROOT%{_libdir}/libpicosat-trace.so
cp -p libpicosat.so $RPM_BUILD_ROOT%{_libdir}/libpicosat.so.%{major}.0.%{version}
ln -s libpicosat.so.%{major}.0.%{version} $RPM_BUILD_ROOT%{_libdir}/libpicosat.so.%{major}
ln -s libpicosat.so.%{major} $RPM_BUILD_ROOT%{_libdir}/libpicosat.so

# Install the binaries
mkdir -p $RPM_BUILD_ROOT%{_bindir}
cp -p picosat picosat.trace picomus $RPM_BUILD_ROOT%{_bindir}

# Install the man pages
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
cp -p %{SOURCE1} %{SOURCE2} %{SOURCE3} $RPM_BUILD_ROOT%{_mandir}/man1

# The LICENSE file is placed in the -libs package rather than the base package,
# because the -libs package is always installed when the base package is
# installed, but not vice versa.
%files
%{_bindir}/picosat*
%{_bindir}/picomus
%{_mandir}/man1/picosat*
%{_mandir}/man1/picomus*

%files -n %{libname}
%doc NEWS
%license LICENSE
%{_libdir}/libpicosat.so.%{major}{,.*}

%files -n %{libnametrace}
%doc NEWS
%license LICENSE
%{_libdir}/libpicosat-trace.so.%{major}{,.*}

%files -n %{libnamedevel}
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/picosat.h
%{_libdir}/libpicosat-trace.so
%{_libdir}/libpicosat.so


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 965-4.mga10
+ Revision: 2223152
- Mageia 10 Mass Rebuild

* Tue May 21 2024 daviddavid <daviddavid> 965-3.mga10
+ Revision: 2065841
- fix sed command
- fix devel pkg name

* Tue Mar 15 2022 umeabot <umeabot> 965-2.mga9
+ Revision: 1792863
- Mageia 9 Mass Rebuild

* Thu Jun 04 2020 joequant <joequant> 965-1.mga8
+ Revision: 1590192
- update to 965

* Fri Feb 14 2020 umeabot <umeabot> 936-15.mga8
+ Revision: 1515927
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 936-14.mga7
+ Revision: 1300262
- Mageia 7 Mass Rebuild

* Tue Jul 10 2018 wally <wally> 936-13.mga7
+ Revision: 1242933
- drop unneeded post/postun scriptlets

* Tue Feb 02 2016 umeabot <umeabot> 936-12.mga6
+ Revision: 931101
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 936-11.mga5
+ Revision: 749271
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 936-10.mga5
+ Revision: 727818
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 936-9.mga5
+ Revision: 687579
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 936-8.mga4
+ Revision: 517455
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 936-7.mga3
+ Revision: 377691
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 17 2012 neoclust <neoclust> 936-6.mga3
+ Revision: 332092
- imported package picosat


* Sun Feb 27 2011 Funda Wang <fwang@mandriva.org> 936-6mdv2011.0
+ Revision: 640458
- rebuild to obsolete old packages

* Tue Feb 22 2011 Alexandre Lissy <alissy@mandriva.com> 936-5
+ Revision: 639278
- Fixing compilation issues and trace patch not being applied

* Mon Feb 21 2011 Alexandre Lissy <alissy@mandriva.com> 936-4
+ Revision: 639143
- fixes major to 1 (as debian)
- fixing install directory of picosat.h as <picosat/picosat.h>

* Mon Feb 21 2011 Alexandre Lissy <alissy@mandriva.com> 936-3
+ Revision: 639137
- Fixes the dependency on library package
- Fixing -devel package name
- Using major for library version

* Mon Feb 21 2011 Alexandre Lissy <alissy@mandriva.com> 936-2
+ Revision: 639126
- Improving packaging for libraries using libname defines
- Fixing the Group for -devel package
- Fixing build issue with make -j
- Fixing typo in RPM group
- Adding picosat package.
- Created package structure for picosat.

